#!/bin/bash

# Make sure only root can run this script
if [ "$(id -u)" != "0" ]; then
   echo " - You must prepend 'sudo' !" 1>&2
   exit 1
fi

echo -e '\n- Set DNS servers / Restore default -\n' ;

rsv_cnf=/etc/resolv.conf ;

# these are Cloudflare's DNS servers
CLF_one=1.1.1.1
CLF_two=1.0.0.1

# these are OpenDNS servers
OPE_one=208.67.222.222
OPE_two=208.67.220.220

PS3='
Please enter your choice : '
options=("  Cloudflare  -      " "  OpenDNS     -      " "  Custom DNS  -      " "  Restore OS  -      " "  Quit        -      ")
select opt in "${options[@]}"
do
	case $opt in
	"  Cloudflare  -      ")
		# check resolv.conf
		if [ ! -L $rsv_cnf ] ;

		then

			# -------------------- runs if resolv.conf is a file --------------------

			# mount root in read/write mode
			mount -o remount,rw / ;

			# add it Cloudflare servers
			echo -e "# Cloudflare servers" > $rsv_cnf ; echo -e "nameserver $CLF_one" >> $rsv_cnf ; echo -e "nameserver $CLF_two" >> $rsv_cnf ;

			resolvectl flush-caches ; 

			# remount root in read only mode
			mount -o remount,ro / ;

			echo -e '\n Cloudflare DNS are set up !\n'

			exit 0

		else

			# -------------------- runs if resolv.conf is a symbolic link --------------------

			# mount root in read/write mode
			mount -o remount,rw / ;

			# delete symbolic link
			rm /etc/resolv.conf ;

			# create file
			touch /etc/resolv.conf ;

			# add it Cloudflare servers
			echo -e "# Cloudflare servers" > $rsv_cnf ; echo -e "nameserver $CLF_one" >> $rsv_cnf ; echo -e "nameserver $CLF_two" >> $rsv_cnf ;

			resolvectl flush-caches ;

                       # remount root in read only mode
                        mount -o remount,ro / ;

			echo -e '\n Cloudflare DNS are set up !\n'

			exit 0

		fi

		;;

	"  OpenDNS     -      ")
		# check resolv.conf
		if [ ! -L $rsv_cnf ] ;

		then

			# -------------------- runs if resolv.conf is a file --------------------

			# mount root in read/write mode
			mount -o remount,rw / ;

			# add it Cloudflare servers
			echo -e "# OpenDNS servers" > $rsv_cnf ; echo -e "nameserver $OPE_one" >> $rsv_cnf ; echo -e "nameserver $OPE_two" >> $rsv_cnf ;

			resolvectl flush-caches ;

			# remount root in read only mode
			mount -o remount,ro / ;

			echo -e '\n OpenDNS servers are set up !\n'

			exit 0

		else

			# -------------------- runs if resolv.conf is a symbolic link --------------------

			# mount root in read/write mode
			mount -o remount,rw / ;

			# delete symbolic link
			rm /etc/resolv.conf ;

			# create file
			touch /etc/resolv.conf ;

			# add it Cloudflare servers
			echo -e "# OpenDNS servers" > $rsv_cnf ; echo -e "nameserver $OPE_one" >> $rsv_cnf ; echo -e "nameserver $OPE_two" >> $rsv_cnf ;

			resolvectl flush-caches ;

                       # remount root in read only mode
                        mount -o remount,ro / ;

			echo -e '\n OpenDNS servers are set up !\n'

			exit 0

		fi

		;;

	"  Custom DNS  -      ")
		# check resolv.conf
		if [ ! -L $rsv_cnf ] ;

		then

			# -------------------- runs if resolv.conf is a file -------------------- 

			# mount root in read/write mode
			mount -o remount,rw / ;

			echo -e "# Custom DNS servers" > $rsv_cnf ; 

                                        read -p " Type primary server : " priDN

					echo -e "nameserver $priDN" >> $rsv_cnf ;

					read -p " Type secondary server : " secDN

					echo -e "nameserver $secDN" >> $rsv_cnf ;

			resolvectl flush-caches ;

			# remount root in read only mode
			mount -o remount,ro / ;

			echo -e '\n Custom DNS are set up !\n'

			exit 0

		else

			# -------------------- runs if resolv.conf is a symbolic link --------------------

			# mount root in read/write mode
			mount -o remount,rw / ;

			# delete symbolic link
			rm /etc/resolv.conf ;

			# create file
			touch /etc/resolv.conf ;

			echo -e "# Custom DNS servers" > $rsv_cnf ;

                                        read -p " Type primary server : " priDN

                                        echo -e "nameserver $priDN" >> $rsv_cnf ;

                                        read -p " Type secondary server : " secDN

                                        echo -e "nameserver $secDN" >> $rsv_cnf ;

			resolvectl flush-caches ;

                       # remount root in read only mode
                        mount -o remount,ro / ;

			echo -e '\n Custom DNS are set up !\n'

			exit 0

		fi

		;;

	"  Restore OS  -      ")
			# mount root in read/write mode
			mount -o remount,rw / ;

			# delete file
			rm /etc/resolv.conf ;

			# recreate symbolic link
			ln -s /run/systemd/resolve/stub-resolv.conf /etc/resolv.conf ;

			resolvectl flush-caches ;

                       # remount root in read only mode
                        mount -o remount,ro / ;

			echo -e '\n OS restored, reboot your device !\n'

			exit 0

		;;
        "  Quit        -      ")
			echo -e '\n  - OS unchanged !\n'

			break
		;;
			*) echo "invalid option $REPLY"
		;;
    esac
done
